/**
 * The Ordered Bayesian Aggregation Scheme
 *
 * @author Bee-Chung Chen (beechung@cs.wisc.edu)
 */
 
package LFA;

import weka.classifiers.Classifier;
import LFA.*;

public class OrderedAggScheme{

  /** Indicate which classifiers will be used */
  protected int[] classifierIndex;
  
  /** The set of new attributes in training table i
   *  (newAttributes[i]).
   *  the classifier on table i is classifierIndex[i]
   */
  public int[][] newAttributes;

  /** The set of old attributes of training table i
   *  (oldAttributes[i]).
   */
  public int[][] oldAttributes;

  private OrderedBayesianEnsemble theEnsemble;

  public OrderedAggScheme(
        OrderedBayesianEnsemble obe,
        int[]   classifier_index,
        int[][] newAttr,
        int[][] oldAttr){
    theEnsemble = obe;
    classifierIndex  = classifier_index;
    newAttributes = newAttr;
    oldAttributes = oldAttr;
  }
  
  public int numClassifiers(){
    return classifierIndex.length;
  }
  
  public Classifier getClassifier(int i) throws Exception{
    if(i < 0 || i >= classifierIndex.length)
        throw new Exception("getClassifier("+i+"), where "+
                            "the number of classifier is "+numClassifiers());
    return theEnsemble.getClassifier(classifierIndex[i]);
  }
  
  public String toString(){
    String[] scheme = theEnsemble.getAggScheme().split(";");
    StringBuffer result = new StringBuffer();
    for(int i=0; i<classifierIndex.length; i++){
        if(i>0) result.append(";");
        result.append(scheme[classifierIndex[i]]);
    }
    return result.toString();
  }

  public String newAttrString(){
    StringBuffer result = new StringBuffer();
    for(int i=0; i<newAttributes.length; i++){
      if(i>0) result.append(";");
      for(int j=0; j<newAttributes[i].length; j++){
        if(j>0) result.append(",");
        result.append(""+(newAttributes[i][j]+1));
      }
    }
    return result.toString();
  }

  public String oldAttrString(){
    StringBuffer result = new StringBuffer();
    for(int i=0; i<oldAttributes.length; i++){
      if(i>0) result.append(";");
      for(int j=0; j<oldAttributes[i].length; j++){
        if(j>0) result.append(",");
        result.append(""+(oldAttributes[i][j]+1));
      }
    }
    return result.toString();
  }

}
