 /**
 * The Symmetric Bayesian Aggregation Scheme
 *
 * @author Bee-Chung Chen (beechung@cs.wisc.edu)
 */
 
package LFA;

import weka.classifiers.Classifier;
import LFA.*;

public class SymmetricAggScheme{

  /** Indicate which classifiers will be used */
  protected int[] classifierIndex;
  
  /** The set of unique attributes of training table i
   *  (uniqueAttributes[i]).
   */
  public int[][] uniqueAttributes;

  /** The set of common attributes of training table i
   *  (commonAttributes[i]).
   */
  public int[][] commonAttributes;

  /** The set of other attributes
   */
  public int[] otherAttributes;
  
  /** Number of tables an attribute occurs in
   */
  public int[] numAttrOccur;
  
  private SymmetricBayesianEnsemble theEnsemble;

  public SymmetricAggScheme(
        SymmetricBayesianEnsemble sbe,
        int[]   classifier_index,
        int[][] uniqueAttr,
        int[][] commonAttr,
        int[]   otherAttr,
        int[]   numAOccur){
    theEnsemble = sbe;
    classifierIndex  = classifier_index;
    uniqueAttributes = uniqueAttr;
    commonAttributes = commonAttr;
    otherAttributes  = otherAttr;
    numAttrOccur     = numAOccur;
  }
  
  public int numClassifiers(){
    return classifierIndex.length;
  }
  
  public Classifier getClassifier(int i) throws Exception{
    if(i < 0 || i >= classifierIndex.length)
        throw new Exception("getClassifier("+i+"), where "+
                            "the number of classifier is "+numClassifiers());
    return theEnsemble.getClassifier(classifierIndex[i]);
  }
  
  public String toString(){
    String[] scheme = theEnsemble.getAggScheme().split(";");
    StringBuffer result = new StringBuffer();
    for(int i=0; i<classifierIndex.length; i++){
        if(i>0) result.append(";");
        result.append(scheme[classifierIndex[i]]);
    }
    return result.toString();
  }

  public String uniqueAttrString(){
    StringBuffer result = new StringBuffer();
    for(int i=0; i<uniqueAttributes.length; i++){
      if(i>0) result.append(";");
      for(int j=0; j<uniqueAttributes[i].length; j++){
        if(j>0) result.append(",");
        result.append(""+(uniqueAttributes[i][j]+1));
      }
    }
    return result.toString();
  }

  public String commonAttrString(){
    StringBuffer result = new StringBuffer();
    for(int i=0; i<commonAttributes.length; i++){
      if(i>0) result.append(";");
      for(int j=0; j<commonAttributes[i].length; j++){
        if(j>0) result.append(",");
        result.append(""+(commonAttributes[i][j]+1));
      }
    }
    return result.toString();
  }

  public String otherAttrString(){
    StringBuffer result = new StringBuffer();
    for(int i=0; i<otherAttributes.length; i++){
      if(i>0) result.append(",");
      result.append(""+(otherAttributes[i]+1));
    }
    return result.toString();
  }

}
